﻿using Conductor.Domain.Models;
using Hotline.CallCenter.BlackLists;
using Hotline.KnowledgeBase;
using Hotline.Share.Dtos.CallCenter;
using Hotline.Share.Dtos.Knowledge;
using Hotline.Share.Dtos.User;
using Hotline.Share.Dtos.Workflow;
using Hotline.Users;
using Mapster;

namespace Hotline.Application.Mappers
{
    public class MapperConfigs : IRegister
    {
        public void Register(TypeAdapterConfig config)
        {
            config.NewConfig<AddBlacklistDto, Blacklist>()
                .Ignore(d => d.Expired)
                .AfterMapping((s, t) => t.InitExpired());

            config.NewConfig<AddUserDto, User>()
                .Map(d => d.Name, x => x.Name ?? x.UserName);

            config.NewConfig<PreDefinition, WorkflowDefinitionDto>()
                .Map(d => d.IsPreDefinition, x => true);

            config.NewConfig<Definition, WorkflowDefinitionDto>()
                .Map(d => d.LastModificationTime, x => x.CreationTime);

            config.NewConfig<KnowledgeApply, KnowledgeApplyPageDto>()
              .Map(d => d.CreationName, x => x.User.Name)
                .Map(d => d.CreationOrgName, x => x.SystemOrganize.OrgName);

            config.NewConfig<Knowledge, KnowledgeDataDto>()
              .Map(d => d.CreationName, x => x.User.Name)
                .Map(d => d.KnowledgeTypeName, x => x.KnowledgeType.SpliceName);

            config.NewConfig<Knowledge, KnowledgeApprovalDataDto>()
            .Map(d => d.CreationName, x => x.User.Name)
              .Map(d => d.KnowledgeTypeName, x => x.KnowledgeType.SpliceName)
                 .Map(d => d.CreateBMName, x => x.SystemOrganize.OrgName);

        }
    }
}
